``Scene`` Module
================

.. autoclass:: kite.Scene
    :show-inheritance:
    :members:

.. autoclass:: kite.scene.BaseScene
    :members:

Scene I/O Modules
---------------------

.. automodule:: kite.scene_io
    :members:

``SceneConfig``
----------------------

.. autoclass:: kite.scene.SceneConfig

Meta Information Container
------------------------------
A ``Scene`` holds several configuration objects:

.. autoclass:: kite.scene.Meta

``Frame``
---------

.. autoclass:: kite.scene.Frame
    :members:

``FrameConfig``
+++++++++++++++

.. autoclass:: kite.scene.FrameConfig


``LOSUnitVectors``
------------------

.. autoclass:: kite.scene.LOSUnitVectors
    :members:
